@@ -4,39 +4,40 @@ use warnings;
 
 package TAP::Harness::Restricted;
 # ABSTRACT: Skip some test files
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use superclass 'TAP::Harness' => 3.18;
 use Path::Tiny;
 
 sub aggregate_tests {
-    my ($self, $aggregate, @tests) = @_;
-    @tests = grep { _file_ok($_) } @tests;
-    return $self->SUPER::aggregate_tests($aggregate, @tests);
+    my ( $self, $aggregate, @tests ) = @_;
+    my %banned_files = map { $_ => undef } map { glob } split " ",
+      $ENV{HARNESS_SKIP} || '';
+    @tests = grep { _file_ok( $_, \%banned_files ) } @tests;
+    return $self->SUPER::aggregate_tests( $aggregate, @tests );
 }
 
 my $maybe_prefix = qr/(?:\d+[_-]?)?/;
 
-my @banned_names = (
-    qr/${maybe_prefix}pod\.t/,
-    qr/${maybe_prefix}pod[_-]?coverage\.t/,
-);
+my @banned_names =
+  ( qr/${maybe_prefix}pod\.t/, qr/${maybe_prefix}pod[_-]?coverage\.t/, );
 
 my @banned_code = (
     qr/use Test::Pod/, # also gets Test::Pod::Coverage
 );
 
 sub _file_ok {
-    my $file = path(shift);
+    my $file         = path(shift);
+    my $banned_files = shift;
     return unless $file->exists;
     my $basename = $file->basename;
     return if grep { $basename =~ $_ } @banned_names;
+    return if exists $banned_files->{ $file->relative };
     my $guts = $file->slurp;
     return if grep { $guts =~ m{$_}ms } @banned_code;
     return 1;
 }
 
-
 1;
 
 
@@ -46,13 +47,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 TAP::Harness::Restricted - Skip some test files
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -80,6 +83,10 @@ File names that look like F<pod.t> or F<pod-coverage.t>, with optional leading n
 
 Files that contain the text C<use Test::Pod>
 
+=item *
+
+Files matching any of the space-separated glob patterns in C<$ENV{HARNESS_SKIP}>
+
 =back
 
 Suggestions for other annoying things to filter out are welcome.
@@ -96,7 +103,7 @@ configuration files, please email the author with ideas before sending a patch.
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/tap-harness-restricted/issues>.
+at L<https://github.com/dagolden/TAP-Harness-Restricted/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -104,14 +111,18 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/tap-harness-restricted>
+L<https://github.com/dagolden/TAP-Harness-Restricted>
 
-  git clone git://github.com/dagolden/tap-harness-restricted.git
+  git clone https://github.com/dagolden/TAP-Harness-Restricted.git
 
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2013 by David Golden.
